#!/usr/bin/env python
# -*- coding: utf-8 -*-
from jira import JIRA
from .board import Board
from .exception import JiraApiException, JiraValidationException
from .filter import Filter
from .issue import Issue
from .project import Project
from .sprint import Sprint


class JiraYak:

    def __init__(self, url, uname, token, project_key):
        """

        :param url:
        :param uname:
        :param token:
        """
        if not url or url is None:
            raise JiraValidationException("[*] Invalid url")

        if not uname or uname is None:
            raise JiraValidationException("[*] Invalid uname")

        if not token or token is None:
            raise JiraValidationException("[*] Invalid token")

        if not project_key or project_key is None:
            raise JiraValidationException("[*] Invalid project_key")

        self.host = url
        self.username = uname
        self.password = token
        self.project_key = project_key
        self.options = {"server": self.host}

        try:
            self.jira = JIRA(self.options, basic_auth=(self.username, self.password))
        except JiraApiException:
            raise JiraApiException("[!] Unable to establish connection with Jira API. Exiting")

        else:
            self.board = Board(self.jira, self.project_key)
            self.filter = Filter(self.jira, self.project_key)
            self.issue = Issue(self.jira, self.project_key)
            self.project = Project(self.jira, self.project_key)
            self.sprint = Sprint(self.jira, self.project_key)
