#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .exception import JiraApiException, JiraValidationException


class Board:

    __module__ = "jira_yak"

    def __init__(self, api, key):
        self.client = api
        self.project_key = key

    def get_board(self, project_key, board_name):
        """Get active Jira board given a project_key.

        :param project_key: Jira project key
        :param board_name: Jira project key
        :return: JSON object representing entire Jira board, otherwise None
        """
        if not project_key or project_key is None:
            raise BoardValidationException("[*] Invalid project_key")

        if not board_name or board_name is None:
            raise BoardValidationException("[*] Invalid board_name")

        boards = None
        try:
            boards = self.client.boards(project_key)
        except BoardException:
            print("[!] Failed to get Jira projects. Retrying in a few seconds.")
            try:
                boards = self.client.boards(project_key)
            except BoardException:
                print("[!] Failed to get Jira projects.")
        finally:
            # boards = None # test!!!
            return next(filter(lambda board: board.name.lower() == board_name.lower(), boards), None)


class BoardException(JiraApiException):
    pass


class BoardValidationException(JiraValidationException):
    pass

