#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .exception import JiraApiException, JiraValidationException


class Filter:

    __module__ = "jira_yak"

    def __init__(self, api, key):
        self.client = api
        self.project_key = key

    def get_jql_filter(self, filter_id):
        """Get a JQL filter.

        :param filter_id: name for the filter
        :return:
        """
        if not filter_id or filter_id is None:
            raise FilterValidationException("[*] Invalid filter_id")

        j_filter = None
        try:
            j_filter = self.client.filter(filter_id)
        except FilterException:
            print("[!] Failed to get Jira filter.\nRetrying in a few seconds.")
            try:
                j_filter = self.client.filter(filter_id)
            except FilterException:
                print("[!] Failed to get Jira filter.")
        finally:
            return j_filter

    def add_new_filter(self, filter_name, new_query):
        """Add a new JQL filter to the Jira project.

        :param filter_name: name for the filter
        :param new_query: filter criteria in the form of a JQL string.
        :return:
        """
        if not filter_name or filter_name is None:
            raise FilterValidationException("[*] Invalid issue_key")

        if not new_query or new_query is None:
            raise FilterValidationException("[*] Invalid or empty query")

        result = None
        try:
            result = self.client.create_filter(filter_name, jql=new_query)
        except FilterException:
            print("[!] Failed to get Jira stories.\nRetrying in a few seconds.")
            try:
                result = self.client.create_filter(filter_name, jql=new_query)
            except FilterException:
                print("[!] Failed to get Jira stories.")
        finally:
            return result

    def update_filter(self, filter_id, new_query):
        """Update an existing JQL filter associated with the Jira project.

        :param filter_id: id for the filter
        :param new_query: filter criteria in the form of a JQL string.
        :return:
        """
        if not filter_id or filter_id is None:
            raise FilterValidationException("[*] Invalid filter_id")

        if not new_query or new_query is None:
            raise FilterValidationException("[*] Invalid or empty query")

        result = None
        try:
            result = self.client.update_filter(filter_id, jql=new_query)
        except FilterException:
            print("[!] Failed to update Jira filter.\nRetrying in a few seconds.")
            try:
                result = self.client.update_filter(filter_id, jql=new_query)
            except FilterException:
                print("[!] Failed to update Jira filter.")
        finally:
            return result


class FilterException(JiraApiException):
    pass


class FilterValidationException(JiraValidationException):
    pass
